import { Body, Controller, Delete, Get, Param, Post, Put, Req, Res } from '@nestjs/common';
import { FastifyRequest, FastifyReply } from 'fastify';
import { NetService, ControllerBase } from '@/core';
import { Environment } from '@/environment';

@Controller()
export class RawMaterialController extends ControllerBase {
  protected readonly http: NetService = new NetService('rawmaterial');

  @Delete('/rawmaterials/batch')
  async removeBatch(
    @Req() request: FastifyRequest,
    @Res() response: FastifyReply,
    @Body() body: any
  ): Promise<any> {
    if (Environment.EnableRuntime) {
      let keys = '';
      if (body && body instanceof Array) {
        keys = body.join(',');
      }
      const url = `/rawmaterial/remove/${keys}`;
      delete request.headers['content-length'];
      this.callAPI(request, response, url);
      return;
    }
    const url = this.parseUrl(request.url);
    const res = await this.http.delete(request, response, url, { data: body });
    return this.parseResponse(request, response, res);
  }

  @Post('/rawmaterials/batch')
  async saveBatch(
    @Req() request: FastifyRequest,
    @Res() response: FastifyReply,
    @Body() body: any
  ): Promise<any> {
    if (Environment.EnableRuntime) {
      const url = `/rawmaterial/save`;
      this.callAPI(request, response, url, body);
      return;
    }
    const url = this.parseUrl(request.url);
    const res = await this.http.post(request, response, url, body);
    return this.parseResponse(request, response, res);
  }
}
